@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::ClassStartup;
 
-our $DATE = '2016-09-09'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-09-29'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -39,7 +39,7 @@ Bencher::Scenario::Accessors::ClassStartup - Benchmark startup of classes using
 
 =head1 VERSION
 
-This document describes version 0.10 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
+This document describes version 0.11 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-29.
 
 =head1 SYNOPSIS
 
@@ -69,6 +69,8 @@ L<Mo> 0.40
 
 L<Mojo::Base>
 
+L<Mojo::Base::XS> 0.07
+
 L<Moo> 2.002004
 
 L<Moose> 2.1805
@@ -97,6 +99,8 @@ L<Perl::Examples::Accessors::Mo> 0.08
 
 L<Perl::Examples::Accessors::MojoBase> 0.08
 
+L<Perl::Examples::Accessors::MojoBaseXS> 0.08
+
 L<Perl::Examples::Accessors::Moo> 0.08
 
 L<Perl::Examples::Accessors::Moose> 0.08
@@ -115,21 +119,15 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Perl::Examples::Accessors::SimpleAccessor (perl_code)
+=item * Perl::Examples::Accessors::ClassTiny (perl_code)
 
-L<Perl::Examples::Accessors::SimpleAccessor>
+L<Perl::Examples::Accessors::ClassTiny>
 
 
 
-=item * Perl::Examples::Accessors::Mouse (perl_code)
+=item * Perl::Examples::Accessors::ObjectSimple (perl_code)
 
-L<Perl::Examples::Accessors::Mouse>
-
-
-
-=item * Perl::Examples::Accessors::MojoBase (perl_code)
-
-L<Perl::Examples::Accessors::MojoBase>
+L<Perl::Examples::Accessors::ObjectSimple>
 
 
 
@@ -139,9 +137,15 @@ L<Perl::Examples::Accessors::ClassAccessor>
 
 
 
-=item * Perl::Examples::Accessors::Hash (perl_code)
+=item * Perl::Examples::Accessors::Mouse (perl_code)
 
-L<Perl::Examples::Accessors::Hash>
+L<Perl::Examples::Accessors::Mouse>
+
+
+
+=item * Perl::Examples::Accessors::MojoBaseXS (perl_code)
+
+L<Perl::Examples::Accessors::MojoBaseXS>
 
 
 
@@ -151,36 +155,6 @@ L<Perl::Examples::Accessors::Moose>
 
 
 
-=item * Perl::Examples::Accessors::Moo (perl_code)
-
-L<Perl::Examples::Accessors::Moo>
-
-
-
-=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
-
-L<Perl::Examples::Accessors::ClassXSAccessor>
-
-
-
-=item * Perl::Examples::Accessors::Scalar (perl_code)
-
-L<Perl::Examples::Accessors::Scalar>
-
-
-
-=item * Perl::Examples::Accessors::ClassTiny (perl_code)
-
-L<Perl::Examples::Accessors::ClassTiny>
-
-
-
-=item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
-
-L<Perl::Examples::Accessors::ClassXSAccessorArray>
-
-
-
 =item * Perl::Examples::Accessors::ClassAccessorArray (perl_code)
 
 L<Perl::Examples::Accessors::ClassAccessorArray>
@@ -193,21 +167,57 @@ L<Perl::Examples::Accessors::Array>
 
 
 
+=item * Perl::Examples::Accessors::Scalar (perl_code)
+
+L<Perl::Examples::Accessors::Scalar>
+
+
+
 =item * Perl::Examples::Accessors::ClassInsideOut (perl_code)
 
 L<Perl::Examples::Accessors::ClassInsideOut>
 
 
 
+=item * Perl::Examples::Accessors::Moo (perl_code)
+
+L<Perl::Examples::Accessors::Moo>
+
+
+
 =item * Perl::Examples::Accessors::Mo (perl_code)
 
 L<Perl::Examples::Accessors::Mo>
 
 
 
-=item * Perl::Examples::Accessors::ObjectSimple (perl_code)
+=item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
 
-L<Perl::Examples::Accessors::ObjectSimple>
+L<Perl::Examples::Accessors::ClassXSAccessorArray>
+
+
+
+=item * Perl::Examples::Accessors::MojoBase (perl_code)
+
+L<Perl::Examples::Accessors::MojoBase>
+
+
+
+=item * Perl::Examples::Accessors::SimpleAccessor (perl_code)
+
+L<Perl::Examples::Accessors::SimpleAccessor>
+
+
+
+=item * Perl::Examples::Accessors::Hash (perl_code)
+
+L<Perl::Examples::Accessors::Hash>
+
+
+
+=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
+
+L<Perl::Examples::Accessors::ClassXSAccessor>
 
 
 
@@ -223,23 +233,24 @@ Benchmark with default options (C<< bencher -m Accessors::ClassStartup >>):
  +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
  | participant                                     | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
  +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
- | Perl::Examples::Accessors::Moose                |     200   |                  195.5 |        1   |   0.0025  |      22 |
- | Perl::Examples::Accessors::Moo                  |      32   |                   27.5 |        5.8 | 6.5e-05   |      20 |
- | Perl::Examples::Accessors::Mouse                |      26   |                   21.5 |        7.2 | 7.2e-05   |      20 |
- | Perl::Examples::Accessors::ClassInsideOut       |      16   |                   11.5 |       11   | 8.8e-05   |      20 |
- | Perl::Examples::Accessors::MojoBase             |      16   |                   11.5 |       12   | 7.7e-05   |      20 |
- | Perl::Examples::Accessors::ClassTiny            |      14   |                    9.5 |       13   | 5.7e-05   |      20 |
- | Perl::Examples::Accessors::ObjectSimple         |      10   |                    5.5 |       10   |   0.00015 |      20 |
- | Perl::Examples::Accessors::ClassXSAccessorArray |      13   |                    8.5 |       15   | 8.8e-05   |      22 |
- | Perl::Examples::Accessors::ClassXSAccessor      |      13   |                    8.5 |       15   | 9.9e-05   |      20 |
- | Perl::Examples::Accessors::ClassAccessor        |      12   |                    7.5 |       15   | 5.7e-05   |      21 |
- | Perl::Examples::Accessors::SimpleAccessor       |       6.9 |                    2.4 |       27   | 2.3e-05   |      20 |
- | Perl::Examples::Accessors::Mo                   |       6.6 |                    2.1 |       28   | 2.6e-05   |      20 |
- | Perl::Examples::Accessors::ClassAccessorArray   |       6.6 |                    2.1 |       28   | 2.1e-05   |      20 |
- | Perl::Examples::Accessors::Scalar               |       4.8 |                    0.3 |       39   | 3.6e-05   |      20 |
- | perl -e1 (baseline)                             |       4.5 |                    0   |       41   | 4.2e-05   |      20 |
- | Perl::Examples::Accessors::Array                |       4.5 |                    0   |       41   | 1.7e-05   |      20 |
- | Perl::Examples::Accessors::Hash                 |       4.5 |                    0   |       42   | 2.2e-05   |      20 |
+ | Perl::Examples::Accessors::Moose                |     170   |                  164.8 |        1   |   0.00046 |      20 |
+ | Perl::Examples::Accessors::Moo                  |      32   |                   26.8 |        5.3 | 4.5e-05   |      20 |
+ | Perl::Examples::Accessors::Mouse                |      26   |                   20.8 |        6.6 | 3.8e-05   |      20 |
+ | Perl::Examples::Accessors::ClassInsideOut       |      17   |                   11.8 |       10   | 5.7e-05   |      20 |
+ | Perl::Examples::Accessors::MojoBase             |      16   |                   10.8 |       11   | 5.8e-05   |      21 |
+ | Perl::Examples::Accessors::ClassTiny            |      15   |                    9.8 |       11   | 5.9e-05   |      21 |
+ | Perl::Examples::Accessors::ClassXSAccessorArray |      13   |                    7.8 |       13   | 6.5e-05   |      20 |
+ | Perl::Examples::Accessors::ObjectSimple         |      13   |                    7.8 |       13   | 4.7e-05   |      21 |
+ | Perl::Examples::Accessors::ClassXSAccessor      |      12   |                    6.8 |       14   | 8.8e-05   |      21 |
+ | Perl::Examples::Accessors::ClassAccessor        |      12   |                    6.8 |       14   | 1.7e-05   |      21 |
+ | Perl::Examples::Accessors::MojoBaseXS           |       9.2 |                    4   |       18   | 4.7e-05   |      20 |
+ | Perl::Examples::Accessors::SimpleAccessor       |       8   |                    2.8 |       20   |   0.0001  |      20 |
+ | Perl::Examples::Accessors::ClassAccessorArray   |       7.3 |                    2.1 |       23   | 3.2e-05   |      20 |
+ | Perl::Examples::Accessors::Mo                   |       7.1 |                    1.9 |       24   | 2.6e-05   |      20 |
+ | perl -e1 (baseline)                             |       5.2 |                    0   |       33   | 3.3e-05   |      20 |
+ | Perl::Examples::Accessors::Array                |       5.2 |                    0   |       33   |   3e-05   |      20 |
+ | Perl::Examples::Accessors::Scalar               |       4.9 |                   -0.3 |       34   | 2.4e-05   |      20 |
+ | Perl::Examples::Accessors::Hash                 |       4.8 |                   -0.4 |       35   | 1.3e-05   |      20 |
  +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 DESCRIPTION
