@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
-our $DATE = '2016-09-09'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-09-29'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -46,7 +46,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.10 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
+This document describes version 0.11 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-29.
 
 =head1 SYNOPSIS
 
@@ -80,6 +80,8 @@ L<Mo> 0.40
 
 L<Mojo::Base>
 
+L<Mojo::Base::XS> 0.07
+
 L<Moo> 2.002004
 
 L<Moose> 2.1805
@@ -110,6 +112,8 @@ L<Perl::Examples::Accessors::Mo> 0.08
 
 L<Perl::Examples::Accessors::MojoBase> 0.08
 
+L<Perl::Examples::Accessors::MojoBaseXS> 0.08
+
 L<Perl::Examples::Accessors::Moo> 0.08
 
 L<Perl::Examples::Accessors::Moose> 0.08
@@ -128,27 +132,19 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Simple::Accessor (perl_code)
+=item * Class::Tiny (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::SimpleAccessor->new
+ Perl::Examples::Accessors::ClassTiny->new
 
 
 
-=item * Mouse (perl_code)
+=item * Object::Simple (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Mouse->new
-
-
-
-=item * Mojo::Base (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::MojoBase->new
+ Perl::Examples::Accessors::ObjectSimple->new
 
 
 
@@ -160,11 +156,19 @@ Code template:
 
 
 
-=item * no generator (hash-based) (perl_code)
+=item * Mouse (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Hash->new
+ Perl::Examples::Accessors::Mouse->new
+
+
+
+=item * Mojo::Base::XS (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::MojoBaseXS->new
 
 
 
@@ -176,46 +180,6 @@ Code template:
 
 
 
-=item * Moo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moo->new
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassXSAccessor->new
-
-
-
-=item * no generator (scalar-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Scalar->new
-
-
-
-=item * Class::Tiny (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassTiny->new
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassXSAccessorArray->new
-
-
-
 =item * Class::Accessor::Array (perl_code)
 
 Code template:
@@ -232,6 +196,14 @@ Code template:
 
 
 
+=item * no generator (scalar-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Scalar->new
+
+
+
 =item * Class::InsideOut (perl_code)
 
 Code template:
@@ -240,6 +212,14 @@ Code template:
 
 
 
+=item * Moo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moo->new
+
+
+
 =item * Mo (perl_code)
 
 Code template:
@@ -248,11 +228,43 @@ Code template:
 
 
 
-=item * Object::Simple (perl_code)
+=item * Class::XSAccessor::Array (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ObjectSimple->new
+ Perl::Examples::Accessors::ClassXSAccessorArray->new
+
+
+
+=item * Mojo::Base (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::MojoBase->new
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::SimpleAccessor->new
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Hash->new
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessor->new
 
 
 
@@ -268,22 +280,23 @@ Benchmark with default options (C<< bencher -m Accessors::Construction >>):
  +-----------------------------+-----------+-----------+------------+---------+---------+
  | participant                 | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-----------------------------+-----------+-----------+------------+---------+---------+
- | Class::InsideOut            |    188000 |    5.31   |       1    |   5e-09 |      20 |
- | Simple::Accessor            |    330000 |    3      |       1.8  | 1.3e-08 |      20 |
- | Class::Tiny                 |    380000 |    2.6    |       2    | 7.5e-09 |      20 |
- | Moose                       |    539000 |    1.86   |       2.86 | 8.3e-10 |      20 |
- | Mo                          |    810000 |    1.2    |       4.3  | 3.7e-09 |      20 |
- | Moo                         |   1030000 |    0.968  |       5.49 |   1e-10 |      20 |
- | Class::Accessor             |   1100000 |    0.88   |       6.1  | 1.7e-09 |      20 |
- | Mouse                       |   1500000 |    0.69   |       7.7  | 3.3e-09 |      20 |
- | no generator (array-based)  |   1780000 |    0.56   |       9.48 | 2.1e-10 |      20 |
- | no generator (hash-based)   |   2170000 |    0.4608 |      11.53 | 1.1e-11 |      28 |
- | Object::Simple              |   2200000 |    0.46   |      12    |   1e-09 |      20 |
- | Mojo::Base                  |   2190000 |    0.456  |      11.6  | 2.7e-10 |      24 |
- | Class::Accessor::Array      |   2390000 |    0.418  |      12.7  | 4.6e-11 |      25 |
- | no generator (scalar-based) |   2450000 |    0.409  |      13    | 2.1e-10 |      20 |
- | Class::XSAccessor           |   3400000 |    0.29   |      18    | 4.2e-10 |      20 |
- | Class::XSAccessor::Array    |   3600000 |    0.28   |      19    | 3.3e-10 |      32 |
+ | Class::InsideOut            |    188000 |    5.32   |      1     | 1.6e-09 |      22 |
+ | Simple::Accessor            |    330000 |    3.1    |      1.7   | 6.1e-09 |      24 |
+ | Class::Tiny                 |    370000 |    2.7    |      2     | 3.3e-09 |      20 |
+ | Moose                       |    520000 |    1.9    |      2.8   | 3.3e-09 |      20 |
+ | Mo                          |    770000 |    1.3    |      4.1   | 2.1e-09 |      20 |
+ | Moo                         |   1019000 |    0.9818 |      5.416 | 1.1e-11 |      20 |
+ | Class::Accessor             |   1100000 |    0.92   |      5.8   | 1.7e-09 |      20 |
+ | Mouse                       |   1400000 |    0.7    |      7.6   |   1e-09 |      20 |
+ | no generator (array-based)  |   1700000 |    0.58   |      9.1   | 8.3e-10 |      20 |
+ | Object::Simple              |   2100000 |    0.48   |     11     | 8.3e-10 |      20 |
+ | no generator (hash-based)   |   2152000 |    0.4646 |     11.45  | 1.1e-11 |      20 |
+ | Mojo::Base                  |   2200000 |    0.455  |     11.7   | 2.1e-10 |      20 |
+ | Class::Accessor::Array      |   2360000 |    0.4238 |     12.55  | 1.1e-11 |      20 |
+ | no generator (scalar-based) |   2400000 |    0.416  |     12.8   | 2.1e-10 |      20 |
+ | Class::XSAccessor           |   3200000 |    0.31   |     17     | 4.5e-10 |      20 |
+ | Mojo::Base::XS              |   3200000 |    0.31   |     17     | 3.9e-10 |      23 |
+ | Class::XSAccessor::Array    |   3500000 |    0.29   |     18     | 8.7e-10 |      20 |
  +-----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
