@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::GeneratorStartup;
 
-our $DATE = '2016-09-09'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-09-29'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::GeneratorStartup - Benchmark startup of various ac
 
 =head1 VERSION
 
-This document describes version 0.10 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
+This document describes version 0.11 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-29.
 
 =head1 SYNOPSIS
 
@@ -65,6 +65,8 @@ L<Mo> 0.40
 
 L<Mojo::Base>
 
+L<Mojo::Base::XS> 0.07
+
 L<Moo> 2.002004
 
 L<Moose> 2.1805
@@ -79,21 +81,15 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Simple::Accessor (perl_code)
+=item * Class::Tiny (perl_code)
 
-L<Simple::Accessor>
+L<Class::Tiny>
 
 
 
-=item * Mouse (perl_code)
+=item * Object::Simple (perl_code)
 
-L<Mouse>
-
-
-
-=item * Mojo::Base (perl_code)
-
-L<Mojo::Base>
+L<Object::Simple>
 
 
 
@@ -103,7 +99,15 @@ L<Class::Accessor>
 
 
 
-=item *  (perl_code)
+=item * Mouse (perl_code)
+
+L<Mouse>
+
+
+
+=item * Mojo::Base::XS (perl_code)
+
+L<Mojo::Base::XS>
 
 
 
@@ -113,34 +117,6 @@ L<Moose>
 
 
 
-=item * Moo (perl_code)
-
-L<Moo>
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-L<Class::XSAccessor>
-
-
-
-=item *  (perl_code)
-
-
-
-=item * Class::Tiny (perl_code)
-
-L<Class::Tiny>
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-L<Class::XSAccessor::Array>
-
-
-
 =item * Class::Accessor::Array (perl_code)
 
 L<Class::Accessor::Array>
@@ -151,21 +127,53 @@ L<Class::Accessor::Array>
 
 
 
+=item *  (perl_code)
+
+
+
 =item * Class::InsideOut (perl_code)
 
 L<Class::InsideOut>
 
 
 
+=item * Moo (perl_code)
+
+L<Moo>
+
+
+
 =item * Mo (perl_code)
 
 L<Mo>
 
 
 
-=item * Object::Simple (perl_code)
+=item * Class::XSAccessor::Array (perl_code)
 
-L<Object::Simple>
+L<Class::XSAccessor::Array>
+
+
+
+=item * Mojo::Base (perl_code)
+
+L<Mojo::Base>
+
+
+
+=item * Simple::Accessor (perl_code)
+
+L<Simple::Accessor>
+
+
+
+=item *  (perl_code)
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+L<Class::XSAccessor>
 
 
 
@@ -181,20 +189,21 @@ Benchmark with default options (C<< bencher -m Accessors::GeneratorStartup >>):
  +--------------------------+-----------+------------------------+------------+-----------+---------+
  | participant              | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
  +--------------------------+-----------+------------------------+------------+-----------+---------+
- | Moose                    |     200   |                  196   |        1   |   0.0027  |      20 |
- | Mouse                    |      26   |                   22   |        7   |   0.00013 |      20 |
- | Moo                      |      20   |                   16   |        9.2 | 2.9e-05   |      20 |
- | Class::Tiny              |      20   |                   16   |       10   |   0.00024 |      20 |
- | Class::InsideOut         |      16   |                   12   |       11   | 2.6e-05   |      20 |
- | Mojo::Base               |      16   |                   12   |       12   | 4.4e-05   |      20 |
- | Class::XSAccessor::Array |      13   |                    9   |       15   | 9.6e-05   |      21 |
- | Object::Simple           |      12   |                    8   |       15   | 4.6e-05   |      20 |
- | Class::XSAccessor        |      12   |                    8   |       16   | 4.1e-05   |      22 |
- | Class::Accessor          |      11   |                    7   |       16   | 2.7e-05   |      20 |
- | Simple::Accessor         |       8   |                    4   |       20   | 8.7e-05   |      20 |
- | Mo                       |       7   |                    3   |       30   |   0.00013 |      21 |
- | Class::Accessor::Array   |       6.6 |                    2.6 |       27   | 3.3e-05   |      20 |
- | perl -e1 (baseline)      |       4   |                    0   |       40   | 6.4e-05   |      20 |
+ | Moose                    |     170   |                  164.4 |        1   |   0.00044 |      20 |
+ | Mouse                    |      26   |                   20.4 |        6.6 |   3e-05   |      20 |
+ | Moo                      |      20   |                   14.4 |        8.5 | 6.9e-05   |      21 |
+ | Class::InsideOut         |      17   |                   11.4 |       10   | 7.4e-05   |      20 |
+ | Mojo::Base               |      17   |                   11.4 |       10   | 8.3e-05   |      20 |
+ | Class::Tiny              |      15   |                    9.4 |       11   | 6.5e-05   |      20 |
+ | Object::Simple           |      13   |                    7.4 |       13   | 6.1e-05   |      20 |
+ | Class::XSAccessor::Array |      12   |                    6.4 |       14   | 1.5e-05   |      20 |
+ | Class::Accessor          |      12   |                    6.4 |       14   | 3.8e-05   |      21 |
+ | Class::XSAccessor        |      12   |                    6.4 |       14   | 7.4e-05   |      21 |
+ | Mojo::Base::XS           |       8.9 |                    3.3 |       19   | 4.7e-05   |      20 |
+ | Class::Accessor::Array   |       7.7 |                    2.1 |       22   | 3.7e-05   |      21 |
+ | Simple::Accessor         |       7.5 |                    1.9 |       23   | 2.1e-05   |      21 |
+ | Mo                       |       7.4 |                    1.8 |       23   | 6.6e-05   |      20 |
+ | perl -e1 (baseline)      |       5.6 |                    0   |       30   | 1.1e-05   |      20 |
  +--------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 DESCRIPTION
