@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Get;
 
-our $DATE = '2016-09-09'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-09-29'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -37,6 +37,7 @@ our $scenario = {
             code_template => "state \$o = do { my \$o = Perl::Examples::Accessors::Array->new; \$o->attr1(42); \$o }; \$o->[0]",
         },
     ],
+    result => 42,
 };
 
 1;
@@ -54,7 +55,7 @@ Bencher::Scenario::Accessors::Get - Benchmark attribute read/get
 
 =head1 VERSION
 
-This document describes version 0.10 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
+This document describes version 0.11 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-29.
 
 =head1 SYNOPSIS
 
@@ -88,6 +89,8 @@ L<Mo> 0.40
 
 L<Mojo::Base>
 
+L<Mojo::Base::XS> 0.07
+
 L<Moo> 2.002004
 
 L<Moose> 2.1805
@@ -116,6 +119,8 @@ L<Perl::Examples::Accessors::Mo> 0.08
 
 L<Perl::Examples::Accessors::MojoBase> 0.08
 
+L<Perl::Examples::Accessors::MojoBaseXS> 0.08
+
 L<Perl::Examples::Accessors::Moo> 0.08
 
 L<Perl::Examples::Accessors::Moose> 0.08
@@ -132,27 +137,19 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Simple::Accessor (perl_code)
+=item * Class::Tiny (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o->attr1(42); $o }; $o->attr1
 
 
 
-=item * Mouse (perl_code)
+=item * Object::Simple (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Mojo::Base (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -164,11 +161,19 @@ Code template:
 
 
 
-=item * no generator (hash-based) (perl_code)
+=item * Mouse (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Mojo::Base::XS (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBaseXS->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -180,38 +185,6 @@ Code template:
 
 
 
-=item * Moo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::Tiny (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
-
-
-
 =item * Class::Accessor::Array (perl_code)
 
 Code template:
@@ -236,6 +209,14 @@ Code template:
 
 
 
+=item * Moo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o->attr1(42); $o }; $o->attr1
+
+
+
 =item * Mo (perl_code)
 
 Code template:
@@ -244,11 +225,43 @@ Code template:
 
 
 
-=item * Object::Simple (perl_code)
+=item * Class::XSAccessor::Array (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Mojo::Base (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -280,23 +293,24 @@ Benchmark with default options (C<< bencher -m Accessors::Get >>):
  +----------------------------+-----------+-----------+------------+---------+---------+
  | participant                | rate (/s) | time (ns) | vs_slowest |  errors | samples |
  +----------------------------+-----------+-----------+------------+---------+---------+
- | Class::Accessor            |   1880000 |       532 |       1    |   2e-10 |      22 |
- | Class::InsideOut           |   2450000 |       409 |       1.3  | 4.7e-11 |      20 |
- | Simple::Accessor           |   2560000 |       390 |       1.36 | 4.6e-11 |      25 |
- | Mojo::Base                 |   4030000 |       248 |       2.15 | 9.9e-11 |      28 |
- | Object::Simple             |   4660000 |       215 |       2.48 | 1.1e-10 |      21 |
- | Mo                         |   4800000 |       210 |       2.5  | 4.2e-10 |      20 |
- | no generator (hash-based)  |   4780000 |       209 |       2.55 | 1.1e-10 |      20 |
- | no generator (array-based) |   5440000 |       184 |       2.89 | 1.1e-10 |      21 |
- | Class::Tiny                |   5500000 |       180 |       2.9  | 2.6e-10 |      29 |
- | Moose                      |   5520000 |       181 |       2.94 |   1e-10 |      26 |
- | Class::Accessor::Array     |   6000000 |       170 |       3.2  | 3.8e-10 |      25 |
- | Mouse                      |   9800000 |       100 |       5.2  |   2e-10 |      23 |
- | Moo                        |  13500000 |        74 |       7.19 |   7e-11 |      20 |
- | Class::XSAccessor          |  14000000 |        73 |       7.3  | 2.1e-10 |      20 |
- | Class::XSAccessor::Array   |  16000000 |        61 |       8.8  | 2.1e-10 |      20 |
- | raw hash access            |  25000000 |        41 |      13    | 6.4e-11 |      28 |
- | raw array access           |  34000000 |        29 |      18    | 4.6e-11 |      22 |
+ | Class::Accessor            |   1800000 |     560   |      1     | 8.3e-10 |      20 |
+ | Class::InsideOut           |   2400000 |     420   |      1.3   |   1e-09 |      20 |
+ | Simple::Accessor           |   2500000 |     400   |      1.4   | 9.9e-10 |      22 |
+ | Mojo::Base                 |   4150000 |     241   |      2.31  | 3.4e-11 |      20 |
+ | Mo                         |   4600000 |     218   |      2.56  |   1e-10 |      20 |
+ | no generator (hash-based)  |   4600000 |     220   |      2.6   | 7.5e-10 |      32 |
+ | Object::Simple             |   4750000 |     211   |      2.64  | 1.2e-10 |      20 |
+ | no generator (array-based) |   5000000 |     200   |      2.8   | 4.2e-10 |      21 |
+ | Class::Tiny                |   5000000 |     200   |      2.8   | 2.6e-10 |      20 |
+ | Moose                      |   5220000 |     191   |      2.91  | 1.1e-10 |      20 |
+ | Class::Accessor::Array     |   5512000 |     181.4 |      3.071 | 1.2e-11 |      20 |
+ | Mouse                      |  10000000 |      99.7 |      5.59  | 3.5e-11 |      20 |
+ | Moo                        |  12000000 |      84   |      6.6   | 4.1e-10 |      21 |
+ | Class::XSAccessor          |  13000000 |      80   |      7     | 4.7e-10 |      20 |
+ | Mojo::Base::XS             |  13000000 |      77   |      7.2   | 2.7e-10 |      20 |
+ | Class::XSAccessor::Array   |  17000000 |      59   |      9.5   | 2.1e-10 |      20 |
+ | raw hash access            |  26000000 |      39   |     14     | 2.4e-10 |      20 |
+ | raw array access           |  28000000 |      36   |     16     | 2.6e-10 |      20 |
  +----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
