@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Set;
 
-our $DATE = '2016-09-09'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-09-29'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -54,7 +54,7 @@ Bencher::Scenario::Accessors::Set - Benchmark attribute write/set
 
 =head1 VERSION
 
-This document describes version 0.10 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
+This document describes version 0.11 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-29.
 
 =head1 SYNOPSIS
 
@@ -88,6 +88,8 @@ L<Mo> 0.40
 
 L<Mojo::Base>
 
+L<Mojo::Base::XS> 0.07
+
 L<Moo> 2.002004
 
 L<Moose> 2.1805
@@ -116,6 +118,8 @@ L<Perl::Examples::Accessors::Mo> 0.08
 
 L<Perl::Examples::Accessors::MojoBase> 0.08
 
+L<Perl::Examples::Accessors::MojoBaseXS> 0.08
+
 L<Perl::Examples::Accessors::Moo> 0.08
 
 L<Perl::Examples::Accessors::Moose> 0.08
@@ -132,27 +136,19 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Simple::Accessor (perl_code)
+=item * Class::Tiny (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o }; $o->attr1(42)
 
 
 
-=item * Mouse (perl_code)
+=item * Object::Simple (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
-
-
-
-=item * Mojo::Base (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
 
 
 
@@ -164,11 +160,19 @@ Code template:
 
 
 
-=item * no generator (hash-based) (perl_code)
+=item * Mouse (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
+
+
+
+=item * Mojo::Base::XS (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBaseXS->new; $o }; $o->attr1(42)
 
 
 
@@ -180,38 +184,6 @@ Code template:
 
 
 
-=item * Moo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::Tiny (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
-
-
-
 =item * Class::Accessor::Array (perl_code)
 
 Code template:
@@ -236,6 +208,14 @@ Code template:
 
 
 
+=item * Moo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o }; $o->attr1(42)
+
+
+
 =item * Mo (perl_code)
 
 Code template:
@@ -244,11 +224,43 @@ Code template:
 
 
 
-=item * Object::Simple (perl_code)
+=item * Class::XSAccessor::Array (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
+
+
+
+=item * Mojo::Base (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::MojoBase->new; $o }; $o->attr1(42)
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o }; $o->attr1(42)
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o }; $o->attr1(42)
 
 
 
@@ -280,23 +292,24 @@ Benchmark with default options (C<< bencher -m Accessors::Set >>):
  +----------------------------+-----------+-----------+------------+---------+---------+
  | participant                | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +----------------------------+-----------+-----------+------------+---------+---------+
- | Simple::Accessor           |    200000 |    5.1    |        1   |   7e-09 |      28 |
- | Class::Accessor            |   1600000 |    0.64   |        7.9 | 8.3e-10 |      20 |
- | Class::InsideOut           |   1900000 |    0.54   |        9.5 | 1.8e-09 |      21 |
- | Moose                      |   3600000 |    0.28   |       18   | 8.1e-10 |      21 |
- | Mojo::Base                 |   3610000 |    0.277  |       18.4 | 1.1e-10 |      20 |
- | Class::Tiny                |   3680000 |    0.271  |       18.8 | 1.1e-10 |      20 |
- | Class::Accessor::Array     |   3800000 |    0.26   |       19   | 1.6e-09 |      21 |
- | Mo                         |   4130000 |    0.242  |       21.1 | 1.3e-10 |      27 |
- | Object::Simple             |   4100000 |    0.24   |       21   |   4e-10 |      22 |
- | no generator (array-based) |   4400000 |    0.23   |       23   | 4.2e-10 |      20 |
- | no generator (hash-based)  |   4610000 |    0.217  |       23.5 | 4.6e-11 |      34 |
- | Mouse                      |   7790000 |    0.128  |       39.7 | 4.7e-11 |      23 |
- | Moo                        |   9810000 |    0.102  |       50   |   7e-11 |      20 |
- | Class::XSAccessor          |  10000000 |    0.097  |       52   | 2.1e-10 |      20 |
- | Class::XSAccessor::Array   |  12000000 |    0.0834 |       61.1 | 4.7e-11 |      29 |
- | raw hash access            |  18000000 |    0.054  |       94   |   7e-11 |      20 |
- | raw array access           |  23000000 |    0.044  |      120   | 2.1e-10 |      20 |
+ | Simple::Accessor           |    195000 |    5.12   |       1    |   5e-09 |      20 |
+ | Class::Accessor            |   1500000 |    0.67   |       7.7  | 1.4e-09 |      23 |
+ | Class::InsideOut           |   1998000 |    0.5005 |      10.23 | 4.6e-11 |      21 |
+ | Moose                      |   3500000 |    0.29   |      18    | 7.5e-10 |      31 |
+ | Class::Tiny                |   3490000 |    0.286  |      17.9  | 5.8e-11 |      20 |
+ | Mojo::Base                 |   3620000 |    0.276  |      18.6  |   1e-10 |      24 |
+ | Mo                         |   3800000 |    0.27   |      19    | 9.1e-10 |      21 |
+ | Object::Simple             |   3960000 |    0.252  |      20.3  | 1.1e-10 |      20 |
+ | Class::Accessor::Array     |   4040000 |    0.248  |      20.7  | 4.6e-11 |      20 |
+ | no generator (hash-based)  |   4460000 |    0.224  |      22.8  | 5.7e-11 |      20 |
+ | no generator (array-based) |   4600000 |    0.22   |      24    | 4.1e-10 |      23 |
+ | Mouse                      |   7200000 |    0.14   |      37    | 5.2e-10 |      20 |
+ | Mojo::Base::XS             |   7300000 |    0.14   |      37    | 4.2e-10 |      20 |
+ | Moo                        |   8390000 |    0.119  |      43    | 4.5e-11 |      20 |
+ | Class::XSAccessor          |   8710000 |    0.115  |      44.6  | 1.2e-11 |      20 |
+ | Class::XSAccessor::Array   |   9600000 |    0.1    |      49    | 2.4e-10 |      24 |
+ | raw hash access            |  14000000 |    0.072  |      71    | 2.1e-10 |      20 |
+ | raw array access           |  20000000 |    0.05   |     100    | 8.9e-10 |      20 |
  +----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
